“utils.RunCmd” is re-exported from “utils.process.RunCmd”. Epydoc
doesn't fully understand this, so we have to refer to the original.
---
 lib/hypervisor/hv_xen.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/lib/hypervisor/hv_xen.py b/lib/hypervisor/hv_xen.py
index 11f9544..8789571 100644
--- a/lib/hypervisor/hv_xen.py
+++ b/lib/hypervisor/hv_xen.py
@@ -351,9 +351,9 @@ class XenHypervisor(hv_base.BaseHypervisor):
     return cmd
 
   def _RunXen(self, args):
     """Wrapper around L{utils.RunCmd} to run Xen command.
 
-    @see: L{utils.RunCmd}
+    @see: L{utils.process.RunCmd}
 
     """
     cmd = [self._GetCommand()]
@@ -351,9 +351,9 @@ class XenHypervisor(hv_base.BaseHypervisor):
 
   def _RunXen(self, args):
-    """Wrapper around L{utils.RunCmd} to run Xen command.
+    """Wrapper around L{utils.process.RunCmd} to run Xen command.
 
-- 
1.8.1

Reply via email to